import React, { useState } from 'react';
import logo from './logo.svg';
import './App.css';

function App() {
  const [image, setImage] = useState({ logo_path: logo });

  const handleDragStart = (event) => {
    changePosition(event.target, event.clientX, event.clientY);
  };

  const handleDragOver = (event) => {
    event.preventDefault();
    changePosition(event.target, event.clientX, event.clientY);
  };

  const handleDrop = (event) => {
    event.preventDefault();
    // Limit the draggable boundary within the drop area
    const container = document.querySelector('.drop-area');
    const rect = container.getBoundingClientRect();
    if (
      // If within the boundary
      event.clientX >= rect.left &&
      event.clientX <= rect.right &&
      event.clientY >= rect.top &&
      event.clientY <= rect.bottom
    ) {
      // When dragging outside the droparea
      setImage({ logo_path: logo });
      changePosition(event.target, rect.left + 100, rect.top + 100);
    }
  };

  function changePosition(draggable, x, y) {
    // Calculate draggable element x, y offset based on the center position
    const offsetX = x - draggable.offsetWidth / 2; 
    const offsetY = y - draggable.offsetHeight / 2;

    // Change draggable element position on a drop event
    draggable.style.left = offsetX + "px";
    draggable.style.top = offsetY + "px";
  }  

  return (
    <div className="App">
      <h1>React Drag and Drop</h1>
      <div
        className="drop-area"
        onDragOver={(event) => handleDragOver(event)}
        onDrop={(event) => handleDrop(event)}
      >
        <img
          src={image.logo_path}
          alt="Logo"
          className="draggable"
          draggable
          onDragStart={(event) => handleDragStart(event)}
        />
      </div>
    </div>
  );
}

export default App;